@@ -1,4 +1,5 @@
 from .archives import *
+from .builtins import *
 from .base_savable import *
 from .archive_factory import *
 from .convenience import *
@@ -14,7 +15,6 @@ from .refs import *
 from .types import *
 from .version import *
 from . import analysis
-from . import builtins
 from . import common_helpers
 from . import mongo
 from . import testing
@@ -25,4 +25,4 @@ _ADDITIONAL = ('analysis', 'mongo', 'buitins', 'common_helpers', 'testing', 'uti
 __all__ = (archives.__all__ + comparators.__all__ + depositors.__all__ + exceptions.__all__ +
            historians.__all__ + convenience.__all__ + process.__all__ + types.__all__ +
            helpers.__all__ + version.__all__ + history.__all__ + archive_factory.__all__ +
-           refs.__all__ + records.__all__ + base_savable.__all__ + _ADDITIONAL)
+           refs.__all__ + records.__all__ + base_savable.__all__ + builtins.__all__ + _ADDITIONAL)
