@@ -11,6 +11,7 @@ __all__ = ('ObjRef',)
 class ObjRef(types.SavableObject):
     """A reference to an object instance"""
     TYPE_ID = uuid.UUID('633c7035-64fe-4d87-a91e-3b7abd8a6a28')
+    IMMUTABLE = True
 
     _obj = None
     _ref = None
@@ -18,6 +19,8 @@ class ObjRef(types.SavableObject):
 
     def __init__(self, obj=None, historian=None):
         super().__init__(historian)
+        assert not (obj is not None and self._historian.is_primitive(obj)), \
+            "Can't create a reference to a primitive type"
         self._obj = obj
 
     def __str__(self):
@@ -57,12 +60,6 @@ class ObjRef(types.SavableObject):
 
         return self._ref == other._ref
 
-    def assign(self, obj):
-        """Assign this reference to point to the given object"""
-        self._obj = obj
-        self._ref = None
-        self._loader = None
-
     def yield_hashables(self, hasher):
         if self._obj is not None:
             yield from hasher.yield_hashables(id(self._obj))
@@ -71,19 +68,20 @@ class ObjRef(types.SavableObject):
             yield from hasher.yield_hashables(self._ref)
 
     def save_instance_state(self, saver):
-        if self._obj is None:
-            return None
-
-        ref = self._ref
-        if ref is None:
+        if self._obj is not None:
             ref = saver.ref(self._obj)
+        else:
+            ref = self._ref
 
-        return ref.to_list()
+        if ref is not None:
+            return ref.to_list()
+
+        return None
 
     def load_instance_state(self, saved_state, loader):
-        if saved_state is None:
-            self._obj = None
-        else:
+        super(ObjRef, self).load_instance_state(saved_state, loader)
+        # Rely on class default values for members
+        if saved_state is not None:
             self._ref = records.Ref(*saved_state)
             self._loader = loader
 
